/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.test.jank;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/** Annotation used to configure a gfx framestats monitor. */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
@Documented
public @interface GfxFrameStatsMonitor {
    /**
     * The name of the process to monitor. Alternatively, if the name begins with '#', it specifies
     * a method that takes no parameters and returns string as the process name to monitor.
     */
    String processName();

    public static final String KEY_AVG_FPS = "framestats-fps";
    public static final String KEY_AVG_JANK_RATE = "framestats-jankrate";
    public static final String KEY_AVG_SLOW_RATE = "framestats-slowrate";
    public static final String KEY_VSYNC_COUNT = "framestats-vsync-count";
    public static final String KEY_FRAME_COUNT = "framestats-frame-count";

    public static final String KEY_UITHREAD_TIME_MEDIAN = "framestats-uithread-median";
    public static final String KEY_UITHREAD_TIME_90TH_PERCENTILE = "framestats-uithread-90";
    public static final String KEY_UITHREAD_TIME_95TH_PERCENTILE = "framestats-uithread-95";
    public static final String KEY_UITHREAD_TIME_99TH_PERCENTILE = "framestats-uithread-99";

    public static final String KEY_RENDERTHREAD_TIME_MEDIAN = "framestats-renderthread-median";
    public static final String KEY_RENDERTHREAD_TIME_90TH_PERCENTILE = "framestats-renderthread-90";
    public static final String KEY_RENDERTHREAD_TIME_95TH_PERCENTILE = "framestats-renderthread-95";
    public static final String KEY_RENDERTHREAD_TIME_99TH_PERCENTILE = "framestats-renderthread-99";

    public static final String KEY_TOTAL_TIME_MEDIAN = "framestats-totaltime-median";
    public static final String KEY_TOTAL_TIME_90TH_PERCENTILE = "framestats-totaltime-90";
    public static final String KEY_TOTAL_TIME_95TH_PERCENTILE = "framestats-totaltime-95";
    public static final String KEY_TOTAL_TIME_99TH_PERCENTILE = "framestats-totaltime-99";
}
